/**
 * Javascript utility functions.
 * (c) TALL, Oxford University.
 *
 * History:
 *   Created: 2005-04-28, David Balch (david.balch@conted.ox.ac.uk)
 *   
 */
 
/**
 * Function:  toggleVis(id)
 * Purpose:  Javascript hide/reveal elements based on their ID.
 * Author:      David Balch (david.balch@conted.ox.ac.uk)
 */
function toggleVis(id) {
 //alert("togglevis");
  e = document.getElementById(id);
  if (e.style.display == "" || e.style.display == "none") {
	  e.style.display = "block";
	} else {
	  e.style.display = "none";
	}
}

/**
 * Function:  timedToggleVis(id, seconds)
 * Purpose:  Javascript hide/reveal elements based on their ID, after a number of seconds.
 * Author:      David Balch (david.balch@conted.ox.ac.uk)
 */
function timedToggleVis(id, seconds) {
  setTimeout("toggleVis('"+id+"')", seconds * 1000);
}

/**
 * Function:  toggleInfo(element);
 * Purpose:  Toggle visibility of spine page elements by class
 * Author:      David Balch (david.balch@conted.ox.ac.uk)
 */
function toggleInfo(element) {
/* Doesn't work in Gecko - see: https://bugzilla.mozilla.org/show_bug.cgi?id=155723 */
    switch(element.id) {
        case 'ToggleInfoAll':
            if (element.innerHTML == 'Show all info') {
                setDisplayByClass('metadata,annotations,mediaobjects', 'block');
                element.innerHTML = 'Hide all info';
            } else {
                setDisplayByClass('metadata,annotations,mediaobjects', 'none');
                element.innerHTML = 'Show all info';
            }
            break;
        case 'ToggleInfoMetadata':
            if (element.innerHTML == 'Show Metadata') {
                setDisplayByClass('metadata', 'block');
                element.innerHTML = 'Hide Metadata';
            } else {
                setDisplayByClass('metadata', 'none');
                element.innerHTML = 'Show Metadata';
            }
            break;
        case 'ToggleInfoAnnotations':
            if (element.innerHTML == 'Show Annotations') {
                setDisplayByClass('annotations', 'block');
                element.innerHTML = 'Hide Annotations';
            } else {
                setDisplayByClass('annotations', 'none');
                element.innerHTML = 'Show Annotations';
            }
            break;
        case 'ToggleInfoMediaobjects':
            if (element.innerHTML == 'Show Mediaobjects') {
                setDisplayByClass('mediaobjects', 'block');
                element.innerHTML = 'Hide Mediaobjects';
            } else {
                setDisplayByClass('mediaobjects', 'none');
                element.innerHTML = 'Show Mediaobjects';
            }
            break;
    }
}
/**
 * Function:  setDisplayByClass(classList, displayValue);
 * Purpose:  Javascript set display values for elements based on their class - e.g. hide/reveal elements.
 * Author:      David Balch (david.balch@conted.ox.ac.uk)
 */
function setDisplayByClass(classList, displayValue) {
    // Split list of classes into an array
    var class_array = classList.split(",")
    
    // Iterate over class array
    for (i=0; i < class_array.length; i++) {
        var thisClass = class_array[i];
        //alert("i: " + i + "\nthisClass: " + thisClass);
        
        // Create array of elements with thisClass
        var thisClassElements = getElementbyClass(thisClass);

        // Iterate over element array
        for (j=0; j < thisClassElements.length; j++) {
            // Set display value
            thisClassElements[j].style.display = displayValue;
            //alert("thisClassElements[j]: " + thisClassElements[j]);
        }
        
    }
}

/**
* getElementbyClass(targetClass) 
* Adapted from: http://www.sitepoint.com/print/rotate-content-with-dhtml
*/
function getElementbyClass(targetClass) {
    customcollection = new Array()
    var inc=0;
    
    //Get all elements
    var alltags=document.all? document.all : document.getElementsByTagName("*");
    
    // Iterate over all elements
    for (k=0; k<alltags.length; k++) {
        // If the element class matches targetClass
        // TODO: We may need to adjust this so that a className *including* targetClass
        if (alltags[k].className==targetClass) {
            // Add element to the array
            customcollection[inc++]=alltags[k];
        }
    }

    return customcollection;
} 


/*
 * userResizer script by David Balch 2005
 * Loosly based on BrainJar.com Generic Drag - GPL license
 */

// Global object to hold resize information.
var resizeObj = new Object();
resizeObj.zIndex = 0;

/**
 * Run the resize
 * event is the handle's onmove
 * targetID is the id of the element to resize
 * objectTweak is an optional var allowing us to cope with nested objects for flash
 */
function uResize(event, targetID, settings) {
  
  resizeObj.settings = settings;
  
  //alert( window.navigator.userAgent.indexOf('Gecko'));
  var el;
  var x, y;

  // Set the resize handle.
  if(event.target) {// DOM
    resizeObj.handleEl = event.target;
    //alert("DOM: " + resizeObj.handleEl);
  } else {// IE
    resizeObj.handleEl = window.event.srcElement;
    //alert("IE: " + resizeObj.handleEl);
  }
  
  // Set the resize target from targetID
  var theID = targetID;
  // We may need to tweak the ID value, to cope with nested object elements.
  if (settings.indexOf('objTweak') != -1) {
    var ua = window.navigator.userAgent;
    
    //alert(ua + "\nGecko: " + ua.indexOf('Gecko') + "\nSafari: " + ua.indexOf('Safari'));
    if (ua.indexOf('Gecko') != -1 && ua.indexOf('Safari') == -1) {
      // If Gecko and not Safari: use targetID.
      theID = targetID;
    } else if (ua.indexOf('Opera') != -1) {
      // If Opera: use targetID.
      theID = targetID + "-activex";
    } else {
      // Otherwise, assume IE and  use targetID + "-activex".
      theID = targetID + "-activex";
    }
  }
  
  resizeObj.targetEl = document.getElementById(theID);
  resizeObj.aspect = resizeObj.targetEl.getAttribute('width')/resizeObj.targetEl.getAttribute('height');
  //alert(ua + "\nid: " + theID + "\nhandle: " + resizeObj.handleEl + "\ntarget: " + resizeObj.targetEl + "\naspect: "+ resizeObj.aspect);

  // Save starting positions of cursor, with respect to the page.
  resizeObj.cursorStartX = event.clientX;
  resizeObj.cursorStartY = event.clientY;
  
  // Save starting size of element.
  resizeObj.targetElStartWidth  = parseInt(resizeObj.targetEl.width,  10);
  resizeObj.targetElStartHeight = parseInt(resizeObj.targetEl.height, 10);

  // Update element's z-index.
  resizeObj.handleEl.style.zIndex = ++resizeObj.zIndex;

  // Capture mousemove and mouseup events on the page.
  try {// DOM
    document.addEventListener("mousemove", resizeGo,   true);
    document.addEventListener("mouseup",   resizeStop, true);
    event.preventDefault();
  }
  catch(er) {// IE
    document.attachEvent("onmousemove", resizeGo);
    document.attachEvent("onmouseup",   resizeStop);
    window.event.cancelBubble = true;
    window.event.returnValue = false;
  }
}

function resizeGo(event) {
  var x, y;
  var dx, dy;
  
  // If resizing flash, let it know so it can hide stuff that shouldn't be scaled.
  if (resizeObj.settings.indexOf('flash') != -1) {
    resizeObj.targetEl.TGotoLabel("/dragBar", "hide")
    //resizeObj.targetEl.TGotoLabel("controls", "hide");
  }
  
  // Get current cursor position with respect to the page.
  x = event.clientX;
  y = event.clientY;
  
  // Get deltas from original
  if (resizeObj.settings.indexOf('freeAspect') != -1) {
    dy = y - resizeObj.cursorStartY
    dx = x - resizeObj.cursorStartX;
  } else {
    dy = y - resizeObj.cursorStartY;
    dx = dy * resizeObj.aspect;
  }
  
  // Resize the target, no smaller than 30px in either dimension
  newWidth = resizeObj.targetElStartWidth + dx;
  newHeight = resizeObj.targetElStartHeight + dy;

  if (newWidth >= 30 && newHeight >= 30) {
    resizeObj.targetEl.setAttribute('width', newWidth);
    resizeObj.targetEl.setAttribute('height', newHeight);
  }
  
  try {// DOM
    event.preventDefault();
  }
  catch(er) {// IE
    window.event.cancelBubble = true;
    window.event.returnValue = false;
  }
}

function resizeStop(event) {
  // Stop capturing mousemove and mouseup events.
  try {// DOM
    document.removeEventListener("mousemove", resizeGo,   true);
    document.removeEventListener("mouseup",   resizeStop, true);
  }
  catch(er) {// IE
    document.detachEvent("onmousemove", resizeGo);
    document.detachEvent("onmouseup",   resizeStop);
  }

  // If resizing flash, let it know so it can restore hidden stuff.
  if (resizeObj.settings.indexOf('flash') != -1) {
    resizeObj.targetEl.SetVariable("/dragBar:restoreSizeWidth", newWidth);
    resizeObj.targetEl.SetVariable("/dragBar:restoreSizeHeight", newHeight);
    resizeObj.targetEl.TGotoLabel("/dragBar", "restore")
    //resizeObj.targetEl.TGotoLabel("controls", "restore");
  }
}


